==> qbs_2.6.1.orig.tar.gz: qbs-src-2.6.1/src/lib/msbuild/msbuild/msbuildimport.cpp <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: http://www.qt.io/licensing
**
** This file is part of Qbs.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms and
** conditions see http://www.qt.io/terms-conditions. For further information
** use the contact form at http://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 or version 3 as published by the Free
** Software Foundation and appearing in the file LICENSE.LGPLv21 and
** LICENSE.LGPLv3 included in the packaging of this file.  Please review the
** following information to ensure the GNU Lesser General Public License
** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, The Qt Company gives you certain additional
** rights.  These rights are described in The Qt Company LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
****************************************************************************/

#include "msbuildimport.h"

#include "imsbuildnodevisitor.h"
#include "msbuildimportgroup.h"
#include "msbuildproject.h"

namespace qbs {

class MSBuildImportPrivate
{
public:
    QString project;
    QString condition;
};

MSBuildImport::MSBuildImport(MSBuildProject *parent)
    : QObject(parent)
    , d(new MSBuildImportPrivate)
{
}

MSBuildImport::MSBuildImport(MSBuildImportGroup *parent)
    : QObject(parent)
    , d(new MSBuildImportPrivate)
{
}

MSBuildImport::~MSBuildImport() = default;

QString MSBuildImport::project() const
{
    return d->project;
}

void MSBuildImport::setProject(const QString &project)
{
    d->project = project;
}

QString MSBuildImport::condition() const
{
    return d->condition;
}

void MSBuildImport::setCondition(const QString &condition)
{
    d->condition = condition;
}

void MSBuildImport::accept(IMSBuildNodeVisitor *visitor) const
{
    visitor->visitStart(this);
    visitor->visitEnd(this);
}

} // namespace qbs

==> qbs_3.1.2.orig.tar.gz: qbs-src-3.1.2/src/lib/msbuild/msbuild/msbuildimport.cpp <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: http://www.qt.io/licensing
**
** This file is part of Qbs.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms and
** conditions see http://www.qt.io/terms-conditions. For further information
** use the contact form at http://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 or version 3 as published by the Free
** Software Foundation and appearing in the file LICENSE.LGPLv21 and
** LICENSE.LGPLv3 included in the packaging of this file.  Please review the
** following information to ensure the GNU Lesser General Public License
** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, The Qt Company gives you certain additional
** rights.  These rights are described in The Qt Company LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
****************************************************************************/

#include "msbuildimport.h"

#include "imsbuildnodevisitor.h"
#include "msbuildimportgroup.h"
#include "msbuildproject.h"

namespace qbs {

class MSBuildImportPrivate
{
public:
    QString project;
    QString condition;
};

MSBuildImport::MSBuildImport()
    : d(new MSBuildImportPrivate)
{
}

MSBuildImport::~MSBuildImport() = default;

QString MSBuildImport::project() const
{
    return d->project;
}

void MSBuildImport::setProject(const QString &project)
{
    d->project = project;
}

QString MSBuildImport::condition() const
{
    return d->condition;
}

void MSBuildImport::setCondition(const QString &condition)
{
    d->condition = condition;
}

void MSBuildImport::accept(IMSBuildNodeVisitor *visitor) const
{
    visitor->visitStart(this);
    visitor->visitEnd(this);
}

} // namespace qbs
